/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief Definition for the notification message: The application information is inserted.
 * @details Input: arg1(uid_t) The user ID.\n
 *          Input: arg3(pkgmgrinfo_appinfo_h) The pkgmgr appinfo handle.\n
 * @since_tizen 5.5
 *
 * @see __appinfo_insert_handler()
 * @see __appinfo_update_handler()
 */
#define AMD_NOTI_MSG_APPINFO_INSERT                                            \
	"appinfo.insert"

/**
 * @brief Definition for the notification message: The application information is removed.
 * @details Input: arg1(uid_t) The user ID.\n
 *          Input: arg3(const char*) The application ID.\n
 * @since_tizen 5.5
 *
 * @see __appinfo_update_handler()
 */
#define AMD_NOTI_MSG_APPINFO_REMOVE                                            \
	"appinfo.remove"

/**
 * @brief Definition for the notification message: The application informations are reloaded.
 * @details Input: arg1(uid_t) The user ID.\n
 * @since_tizen 5.5
 *
 * @see __reload_appinfo()
 */
#define AMD_NOTI_MSG_APPINFO_RELOAD                                            \
	"appinfo.reload"

/**
 * @brief Definition for the notification message: The application informations are loaded.
 * @details Input: arg1(uid_t) The user ID.\n
 * @since_tizen 5.5
 *
 * @see _appinfo_load()
 */
#define AMD_NOTI_MSG_APPINFO_LOAD                                              \
	"appinfo.load"

/**
 * @brief Definition for the notification message: The application informations are unloaded.
 * @details Input: arg1(uid_t) The user ID.\n
 * @since_tizen 5.5
 *
 * @see _appinfo_unload()
 */
#define AMD_NOTI_MSG_APPINFO_UNLOAD                                            \
	"appinfo.unload"
/**
 * @brief Definition for the notification message: The package update is failed.
 * @details Input: arg1(uid_t) The user ID.\n
 *          Input: arg3(const char *) The package ID.\n
 * @since_tizen 5.5
 *
 * @see __package_event_cb()
 */
#define AMD_NOTI_MSG_APPINFO_PACKAGE_UPDATE_ERROR                              \
	"appinfo.package.update.error"

/**
 * @brief Definition for the notification message: The package is deleted.
 * @details Input: arg1(uid_t) The user ID.\n
 *                 arg3(const char *) The package ID.\n
 * @since_tizen 5.5
 *
 * @see __package_event_cb()
 */
#define AMD_NOTI_MSG_APPINFO_PACKAGE_UNINSTALL_END                             \
	"appinfo.package.uninstall.end"

/**
 * @brief Definition for the notification message: The package is installed.
 * @details Input: arg1(uid_t) The user ID.\n
 *          Input: arg3(const char *) The package ID.\n
 * @since_tizen 5.5
 *
 * @see __package_event_cb()
 */
#define AMD_NOTI_MSG_APPINFO_PACKAGE_INSTALL_END                               \
	"appinfo.package.install.end"

/**
 * @brief Definition for the notification message: The package is updated.
 * @details Input: arg1(uid_t) The user ID.\n
 *          Input: arg3(const char *) The package ID.\n
 * @since_tizen 5.5
 *
 * @see __package_event_cb()
 */
#define AMD_NOTI_MSG_APPINFO_PACKAGE_UPDATE_END                                \
	"appinfo.package.update.end"

/**
 * @brief Definition for the notification message: The application is enabled.
 * @details Input: arg1(uid_t) The user ID.\n
 *          Input: arg3(const char *) The application ID.\n
 * @since_tizen 5.5
 *
 * @see __handle_app_event_end()
 */
#define AMD_NOTI_MSG_APPINFO_APP_ENABLED_END                                   \
	"appinfo.app.enabled.end"

/**
 * @brief Definition for the notification message: The application is disabled.
 * @details Input: arg1(uid_t) The user ID.\n
 *          Input: arg3(const char *) The application ID.\n
 * @since_tizen 5.5
 *
 * @see __handle_app_event_end()
 */
#define AMD_NOTI_MSG_APPINFO_APP_DISABLED_END                                  \
	"appinfo.app.disabled.end"

/**
 * @brief Definition for the notification message: The running applications in the background should be terminated.
 * @since_tizen 5.5
 *
 * @see __check_running_uiapp_list()
 */
#define AMD_NOTI_MSG_APP_STATUS_TERM_BG_APPS                                   \
	"app_status.term_bg_apps"

/**
 * @brief Definition for the notification message: The status information of the running application will be destroyed.
 * @details Input: arg3(amd_app_status_h) The app status handle.\n
 * @since_tizen 5.5
 *
 * @see __destroy_app_status()
 */
#define AMD_NOTI_MSG_APP_STATUS_DESTROY                                        \
	"app_status.destroy"

/**
 * @brief Definition for the notification message: The status information is added.
 * @details Input: arg3(amd_app_status_h) The app status handle.\n
 * @since_tizen 5.5
 *
 * @see _app_status_add_app_info()
 */
#define AMD_NOTI_MSG_APP_STATUS_ADD                                            \
	"app_status.add"

/**
 * @brief Definition for the notification message: The status information will be updated.
 * @details Input: arg1(int) The status.\n
 *          Input: arg3(amd_app_status_h) The app status handle.\n
 * @since_tizen 5.5
 *
 * @see _app_status_update_status()
 */
#define AMD_NOTI_MSG_APP_STATUS_UPDATE_STATUS_START                            \
	"app_status.update_status.start"

/**
 * @brief Definition for the notification message: The status information is updated.
 * @details Input: arg1(bool) The flag if true, the status is updated forcedly.\n
 *          Input: arg2(bool) The flag if ture, the group info has to be updated.\n
 *          Input: arg3(amd_app_status_h) The app status handle.\n
 * @since_tizen 5.5
 *
 * @see _app_status_update_status()
 */
#define AMD_NOTI_MSG_APP_STATUS_UPDATE_STATUS_END                              \
	"app_status.update_status.end"

/**
 * @brief Definition for the notification message: The status information will be destroyed.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(uid_t) The user ID.\n
 *          Input: arg3(amd_app_status_h) The app status handle.\n
 * @since_tizen 5.5
 *
 * @see _app_status_cleanup()
 */
#define AMD_NOTI_MSG_APP_STATUS_CLEANUP                                        \
        "app_status.cleanup"

/**
 * @brief Definition for the notification message: The application is sending the registration request.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg3(amd_appinfo_h) The app info handle.\n
 * @since_tizen 5.5
 *
 * @see _app_status_register_pid()
 */
#define AMD_NOTI_MSG_APP_STATUS_APP_REGISTER_PID                               \
	"app_status.app_register_pid"

/**
 * @brief Definition for the notification message: The status information of the running component is added.
 * @details Input: arg3(amd_comp_status_h) The comp status handle.\n
 * @since_tizen 5.5
 *
 * @see _comp_status_add_comp_info()
 */
#define AMD_NOTI_MSG_COMP_STATUS_ADD                                           \
	"comp_status.add"

/**
 * @brief Definition for the notification message: The status information of the running component is destroyed.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(uid_t) The user ID.\n
 *          Input: arg3(const char *) The instance ID.\n
 * @since_tizen 5.5
 *
 * @see __dispatch_comp_notify_exit()
 */
#define AMD_NOTI_MSG_COMP_STATUS_NOTIFY_EXIT                                   \
        "comp_status.notify.exit"

/**
 * @brief Definition for the notification message: The status information of the running component is updated.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(bool) The flag if true, the group info has to be updated.\n
 *          Input: arg3(amd_comp_status_h) The comp status handle.\n
 * @since_tizen 5.5
 *
 * @see __dispatch_comp_status_update()
 */
#define AMD_NOTI_MSG_COMP_STATUS_UPDATE_STATUS_END                             \
	"comp_status.update_status.end"

/**
 * @brief Definition for the notification message: The poweroff state is changed.
 * @details Input: arg1(int) The state of the poweroff.
 * @since_tizen 5.5
 *
 * @see __poweroff_state_cb()
 */
#define AMD_NOTI_MSG_LAUNCH_POWEROFF_STATE_CHANGE                              \
	"poweroff.state.change"

/**
 * @brief Definition for the notification message: The termination request will be sent to the running application.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg3(amd_request_h) The request handle.\n
 * @since_tizen 5.5
 *
 * @see _term_app()
 * @see _term_app_v2()
 */
#define AMD_NOTI_MSG_LAUNCH_TERM_APP_START                                     \
	"launch.term_app.start"

/**
 * @brief Definition for the notification message: The termination request will be sent to the running application.
 * @details If the application is running in the background, the application will be terminated.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg3(amd_request_h) The request handle.\n
 * @since_tizen 5.5
 *
 * @see _term_bgapp()
 */
#define AMD_NOTI_MSG_LAUNCH_TERM_BGAPP_START                                   \
	"launch.term_bgapp.start"

/**
 * @brief Definition for the notification message: The recv() is failed.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(uid_t) The user Id.\n
 *          Input: arg4(bundle *) The bundle object.\n
 * @since_tizen 5.5
 *
 * @see __reply_handler()
 */
#define AMD_NOTI_MSG_LAUNCH_RECV_ERROR                                         \
	"launch.recv.error"

/**
 * @brief Definition for the notification message: The recv() is failed by timeout.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(uid_t) The user ID.\n
 *          Input: arg4(bundle *) The bundle object.\n
 * @since_tizen 5.5
 *
 * @see __recv_timeout_handler()
 */
#define AMD_NOTI_MSG_LAUNCH_RECV_TIMEOUT                                       \
	"launch.recv.timeout"

/**
 * @brief Definition for the notification message: The launch request will be sent to the running application.
 * @details The launch request is will be sent to the running application.
 *          This message is occurred before sending the request.
 * @details Input: arg1(int) The AUL command.\n
 *          Input: arg2(int) The process ID.\n
 *          Input: arg3(amd_request_h) The request handle.\n
 *          Input: arg4(bundle *) The bundle object.\n
 * @since_tizen 5.5
 *
 * @see __nofork_processing()
 */
#define AMD_NOTI_MSG_LAUNCH_DO_STARTING_APP_RELAUNCH_START                     \
	"launch.do_starting_app.relaunch.start"

/**
 * @brief Definition for the notification message: The application is running in the foreground.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(uid_t) The user ID.\n
 *          Input: arg3(amd_app_status_h) The app status handle.\n
 * @since_tizen 5.5
 *
 * @see __app_status_handler()
 */
#define AMD_NOTI_MSG_LAUNCH_STATUS_FG                                          \
	"launch.status.fg"

/**
 * @brief Definition for the notification message: The application is running in the background.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(uid_t) The user ID.\n
 *          Input: arg3(amd_app_status_h) The app status handle.\n
 * @since_tizen 5.5
 *
 * @see __app_status_handler()
 */
#define AMD_NOTI_MSG_LAUNCH_STATUS_BG                                          \
	"launch.status.bg"

/**
 * @brief Definition for the notification message: The application has a focus.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(uid_t) The user ID.\n
 *          Input: arg3(amd_app_status_h) The app status handle.\n
 * @since_tizen 5.5
 *
 * @see __app_status_handler()
 */
#define AMD_NOTI_MSG_LAUNCH_STATUS_FOCUS                                       \
	"launch.status.focus"

/**
 * @brief Definition for the notification message: The window of the application is hidden.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(uid_t) The user ID.\n
 *          Input: arg3(amd_app_status_h) The app status handle.\n
 * @since_tizen 5.5
 *
 * @see __app_status_handler()
 */
#define AMD_NOTI_MSG_LAUNCH_STATUS_HIDE                                        \
	"launch.status.hide"

/**
 * @brief Definition for the notification message: The application is launched.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(uid_t) The user ID.\n
 *          Input: arg3(amd_app_status_h) The app status handle.\n
 * @since_tizen 5.5
 *
 * @see __app_status_handler()
 */
#define AMD_NOTI_MSG_LAUNCH_STATUS_LAUNCH                                      \
	"launch.status.launch"

/**
 * @brief Definition for the notification message: The launch request is started.
 * @details Input: arg3(amd_request_h) The request handle.\n
 *          Input: arg4(bundle *) The bundle object.\n
 * @since_tizen 5.5
 *
 * @see __dispatch_app_start()
 * @see __dispatch_rpc_port_prepare_stub()
 */
#define AMD_NOTI_MSG_LAUNCH_APP_START_START                                    \
	"launch.app_start.start"

/**
 * @brief Definition for the notification message: The launch request is failed.
 * @details Input: arg1(int) The result.\n
 * @since_tizen 5.5
 *
 * @see __dispatch_app_start()
 * @see __dispatch_rpc_port_prepare_stub()
 */
#define AMD_NOTI_MSG_LAUNCH_FAIL                                               \
	"launch.fail"

/**
 * @brief Definition for the notification message: The launch request is pended.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(bool) The flag if true, the request is for the background launch.
 *          Input: arg3(amd_request_h) The request handle.\n
 *          Input: arg4(amd_request_reply_h) The request reply handle.\n
 * @since_tizen 5.5
 *
 * @see __dispatch_app_start()
 */
#define AMD_NOTI_MSG_LAUNCH_APP_START_PEND                                     \
	"launch.app_start.pend"

/**
 * @brief Definition for the notification message: The launch request is ended.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(bool) The flag if true, the request is for the background launch.
 *          Input: arg3(amd_request_h) The request handle.\n
 *          Input: arg4(bundle *) The bundle object.\n
 * @since_tizen 5.5
 *
 * @see __dispatch_app_start()
 * @see __dispatch_rpc_port_prepare_stub()
 */
#define AMD_NOTI_MSG_LAUNCH_APP_START_END                                      \
	"launch.app_start.end"

/**
 * @brief Definition for the notification message: The app result request is started.
 * @details Input: arg1(int) The process group ID.\n
 *          Input: arg2(uid_t) The user ID.\n
 *          Input: arg3(const char *) The application ID.\n
 *          Input: arg4(bundle *b) The bundle object.\n
 * @since_tizen 5.5
 *
 * @see __dispatch_app_result()
 */
#define AMD_NOTI_MSG_LAUNCH_APP_RESULT_START                                   \
	"launch.app_result.start"

/**
 * @brief Definition for the notification message: The app result request is ended.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(uid_t) The user ID.\n
 *          Input: arg3(int) The result.\n
 * @since_tizen 5.5
 *
 * @see __dispatch_app_result()
 */
#define AMD_NOTI_MSG_LAUNCH_APP_RESULT_END                                     \
	"launch.app_result.end"

/**
 * @brief Definition for the notification message: The app startup signal request is ended.
 * @details The request is received from the launched app process.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg3(amd_request_h) The request handle.\n
 * @since_tizen 5.5
 *
 * @see __dispatch_app_startup_signal()
 */
#define AMD_NOTI_MSG_LAUNCH_APP_STARTUP_SIGNAL_END                             \
	"launch.app_startup_signal.end"

/**
 * @brief Definition for the notification message: Preparing the launch request is started.
 * @details Input: arg1(uid_t) The user ID.\n
 *          Input: arg3(amd_appinfo_h) The appinfo handle.\n
 * @since_tizen 5.5
 *
 * @see __prepare_starting_app()
 */
#define AMD_NOTI_MSG_LAUNCH_PREPARE_START                                      \
	"launch.prepare.start"

/**
 * @brief Definition for the notification message: Preparing the launch request that is launching the UI application is started.
 * @details If the return value is less than AMD_NOTI_STOP, the launch request is stopped. And then, the caller process gets a negative error value.
 * @details Input: arg1(int) The status of the application.\n
 *          Input: arg2(uid_t) The user ID.\n
 *          Input: arg3(amd_launch_context_h) The launch context handle.\n
 *          Input: arg4(bundle *) The bundle object.\n
 * @since_tizen 5.5
 *
 * @see __prepare_starting_app()
 */
#define AMD_NOTI_MSG_LAUNCH_PREPARE_UI_START                                   \
	"launch.prepare.ui.start"

/**
 * @brief Definition for the notification message: Preparing the launch request that is launching the UI application is ended.
 * @details If the return value is less than AMD_NOTI_STOP, the launch request is stopped. And then, the caller process gets a negative error value.
 * @details Input: arg1(bool) The flag if true, the request is for the background launch.
 *          Input: arg2(int) The process ID of the caller.\n
 *          Input: arg3(amd_app_status_h) The app status handle.\n
 * @since_tizen 5.5
 *
 * @see __prepare_starting_app()
 */
#define AMD_NOTI_MSG_LAUNCH_PREPARE_UI_END                                     \
	"launch.prepare.ui.end"

/**
 * @brief Definition for the notification message: Preparing the launch request that is launching the Service application is.
 * @details If the return value is less than AMD_NOTI_STOP, the launch request is stopped. And then, the caller process gets a negative error value.
 * @details Input: arg3(amd_request_h) The request handle.\n
 * @since_tizen 5.5
 *
 * @see __prepare_starting_app()
 */
#define AMD_NOTI_MSG_LAUNCH_PREPARE_SERVICE                                    \
	"launch.prepare.service"

/**
 * @brief Definition for the notification message: Preparing the launch request that is launching the Widget application is.
 * @details If the return value is less than AMD_NOTI_STOP, the launch request is stopped. And then, the caller process gets a negative error value.
 * @details Input: arg3(amd_request_h) The request handle.\n
 * @since_tizen 5.5
 *
 * @see __prepare_starting_app()
 */
#define AMD_NOTI_MSG_LAUNCH_PREPARE_WIDGET                                     \
	"launch.prepare.widget"

/**
 * @brief Definition for the notification message: Preparing the launch request that is launching the Component-based application is started.
 * @details If the return value is less than AMD_NOTI_STOP, the launch request is stopped. And then, the caller process gets a negative error value.
 * @details Input: arg1(int) The status of the application.\n
 *          Input: arg2(uid_t) The user ID.\n
 *          Input: arg3(amd_launch_context_h) The launch context handle.\n
 *          Input: arg4(bundle *) The bundle object.\n
 * @since_tizen 5.5
 *
 * @see __prepare_starting_app()
 */
#define AMD_NOTI_MSG_LAUNCH_PREPARE_COMPONENT_BASED_START                      \
	"launch.prepare.component-based.start"

/**
 * @brief Definition for the notification message: Preparing the launch request is ended.
 * @details Input: arg1(int) The process ID of the caller.\n
 *          Input: arg2(uid_t) The user ID.\n
 *          Input: arg3(amd_appinfo_h) The appinfo handle.\n
 *          Input: arg4(bundle *) The bundle object.\n
 * @since_tizen 5.5
 *
 * @see __prepare_starting_app()
 */
#define AMD_NOTI_MSG_LAUNCH_PREPARE_END                                        \
	"launch.prepare.end"

/**
 * @brief Definition for the notification message: The application is dead.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(uid_t) The user ID.\n
 *          Input: arg3(amd_app_status_h) The app status handle.\n
 * @since_tizen 5.5
 *
 * @see __kill_and_cleanup_status()
 * @see __app_dead_handler()
 */
#define AMD_NOTI_MSG_LAUNCH_MAIN_APP_DEAD                                      \
	"main.app_dead"

/**
 * @brief Definition for the notification message: The re-launch request is canceled.
 * @details Input: arg1(int) The result.\n
 * @since_tizen 5.5
 *
 * @see __do_starting_app()
 */
#define AMD_NOTI_MSG_LAUNCH_DO_STARTING_APP_RELAUNCH_CANCEL                    \
	"launch.do_starting_app.relaunch.cancel"

/**
 * @brief Definition for the notification message: The re-launch request is end.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg3(amd_launch_context_h) The launch context handle.\n
 *          Input: arg4(amd_request_h) The request handle.\n
 * @since_tizen 5.5
 * @see __do_starting_app()
 */
#define AMD_NOTI_MSG_LAUNCH_DO_STARTING_APP_RELAUNCH_END                       \
	"launch.do_starting_app.relaunch.end"

/**
 * @brief Definition for the notification message: The launch request will be started.
 * @details This message is occurred before sending the launch request to the launchpad.
 *          While getting the request in the launchpad, the launchpad make a child process to launch the application.
 * @details Input: arg1(int) The AUL command.\n
 *          Input: arg2(bool) The flag if true, the request is for background launch.\n
 *          Input: arg3(amd_launch_context_h) The launch context handle.\n
 *          Input: arg4(bundle *) The bundel object.\n
 * @since_tizen 5.5
 *
 * @see __do_starting_app()
 */
#define AMD_NOTI_MSG_LAUNCH_DO_STARTING_APP_START                              \
	"launch.do_starting_app.start"

/**
 * @brief Definition for the notification message: The launch request is canceled.
 * @details Input: arg1(int) The result.\n
 * @since_tizen 5.5
 *
 * @see __do_starting_app()
 */
#define AMD_NOTI_MSG_LAUNCH_DO_STARTING_APP_CANCEL                             \
	"launch.do_starting_app.cancel"

/**
 * @brief Definition for the notification message: The launch request is ended.
 * @details The app process is created.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(bool) The flag if true, the request is for background launch.\n
 *          Input: arg3(amd_launch_context_h) The launch context.\n
 *          Input: arg4(amd_request_h) The request handle.\n
 * @since_tizen 5.5
 *
 * @see __do_starting_app()
 */
#define AMD_NOTI_MSG_LAUNCH_DO_STARTING_APP_END                                \
	"launch.do_starting_app.end"

/**
 * @brief Definition for the notification message: The launch request is completed.
 * @details This message is occurred before saving some informations(app_status and comp_status).
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(bool) The flag if true, a new process is created.\n
 *          Input: arg3(amd_appinfo_h) The appinfo handle.\n
 *          Input: arg4(bundle *) The bundle object.\n
 * @since_tizen 5.5
 *
 * @see __complete_starting_app()
 */
#define AMD_NOTI_MSG_LAUNCH_COMPLETE_START                                     \
	"launch.complete.start"

/**
 * @brief Definition for the notification message: The launch request is completed.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(uid_t) The user ID.\n
 *          Input: arg3(amd_appinfo_h) The appinfo handle.\n
 *          Input: arg4(bundle *) The bundle object.\n
 * @since_tizen 5.5
 *
 * @see __complete_starting_app()
 */
#define AMD_NOTI_MSG_LAUNCH_COMPLETE_END                                       \
	"launch.complete.end"

/**
 * @brief Definition for the notification message: The user login is starting.
 * @details Input: arg1(uid_t) The user ID.\n
 *          Input: arg2(int) The state of the user session.\n
 * @since_tizen 5.5
 *
 * @see __user_login()
 */
#define AMD_NOTI_MSG_LOGIN_MONITOR_LOGIN_START                                 \
	"login_monitor.login.start"

/**
 * @brief Definition for the notification message: The user logged in.
 * @details Input: arg1(uid_t) The user ID.\n
 *          Input: arg2(int) The state of the user session.\n
 * @since_tizen 5.5
 *
 * @see __user_login()
 */
#define AMD_NOTI_MSG_LOGIN_MONITOR_LOGIN                                       \
	"login_monitor.login"

/**
 * @brief Definition for the notification message: The user logged out.
 * @details Input: arg1(uid_t) The user ID.\n
 *          Input: arg2(int) The state of the user session.\n
 * @since_tizen 5.5
 *
 * @see __user_logout()
 */
#define AMD_NOTI_MSG_LOGIN_MONITOR_LOGOUT                                      \
	"login_monitor.logout"

/**
 * @brief Definition for the notification message: The booting is finished.
 * @details The message is occurred after the system session and the user session are ready.
 * @details Input: arg1(uid_t) The user ID.\n
 * @since_tizen 5.5
 *
 * @see __startup_finished_cb()
 */
#define AMD_NOTI_MSG_LOGIN_MONITOR_STARTUP_FINISHED                            \
	"startup.finished"

/**
 * @brief Definition for the notification message: The loader process is dead.
 * @details Input: arg1(int) The process ID.\n
 * @since_tizen 5.5
 *
 * @see __app_dead_handler()
 */
#define AMD_NOTI_MSG_MAIN_APP_DEAD_LOADER                                      \
	"main.app_dead.loader"

/**
 * @brief Definition for the notification message: The app process is dead.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(uid_t) The user ID.\n
 *          Input: arg3(amd_app_status_h) The app status handle.\n
 * @since_tizen 5.5
 *
 * @see __app_dead_handler()
 */
#define AMD_NOTI_MSG_MAIN_APP_DEAD                                             \
	"main.app_dead"

/**
 * @brief Definition for the notification message: The user is initialized.
 * @details Input: arg1(uid_t) The user ID.\n
 * @since_tizen 5.5
 *
 * @see _request_usr_init()
 */
#define AMD_NOTI_MSG_REQUEST_USER_INIT                                         \
	"request.user_init"

/**
 * @brief Definition for the notification message: The watchdog signal will be sent.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(int) The signal number.\n
 * @since_tizen 5.5
 *
 * @see _signal_send_watchdog()
 */
#define AMD_NOTI_MSG_SIGNAL_SEND_WATCHDOG_START                                \
	"signal.send_watchdog.start"

/**
 * @brief Definition for the notification message: The memory status is changed to normal.
 * @since_tizen 5.5
 *
 * @see __memory_status_changed_cb()
 */
#define AMD_NOTI_MSG_UTIL_LOW_MEMORY_NORMAL                                    \
	"util.low_memory.normal"

/**
 * @brief Definition for the notification message: Saving a RUA information is started.
 * @details If the return value is less than AMD_NOTI_STOP, the RUA information is not saved.
 * @details Input: arg3(amd_request_h) The request handle.\n
 *          Input: arg4(bundle *) The bundle object.\n
 * @since_tizen 5.5
 *
 * @see __on_launch_pending()
 * @see __on_launch_ending()
 * @remarks This message is sent from the `amd-mod-rua` module.
 */
#define AMD_NOTI_MSG_RUA_SAVE_CRITICAL                                         \
	"rua.save.critical"

/**
 * @brief Definition for the notification message: The app screen is updated.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(int) The window ID.\n
 * @since_tizen 5.5
 *
 * @see __on_launch_status()
 * @remarks This message is sent from the `amd-mod-screen-connector` module.
 */
#define AMD_NOTI_MSG_SCREEN_CONNECTOR_APP_SCREEN_UPDATE                        \
	"screen_connector.app_screen.update"

/**
 * @brief Definition for the notification message: Recycling the window is ended.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(int) The window ID.\n
 * @since_tizen 5.5
 *
 * @see __app_group_context_do_recycle()
 * @remarks Thie message is sent from the `amd-mod-ui-core` module.
 */
#define AMD_NOTI_MSG_APP_GROUP_DO_RECYCLE_END                                  \
	"app_group.do_recycle.end"

/**
 * @brief Definition for the notification message: The window is set.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(int) The window ID.\n
 *          Input: arg3(const char *) The instance ID.\n
 * @remarks The instance ID(arg3) can be nullptr.
 * @since_tizen 5.5
 *
 * @see __dispatch_app_group_set_window()
 * @see __dispatch_app_group_set_window_v2()
 * @remarks Thie message is sent from the `amd-mod-ui-core` module.
 */
#define AMD_NOTI_MSG_APP_GROUP_WINDOW_SET                                      \
	"app_group.window.set"

/**
 * @brief Definition for the notification message: The wayland interface is added.
 * @details The interface is `tizen_input_device_manager`.
 * @details Input: arg1(int) The interface ID.\n
 *          Input: arg2(int) The version.\n
 *          Input: arg3(struct wl_registry *) The wayland registry.\n
 * @since_tizen 5.5
 *
 * @see __wl_listener_cb()
 * @remarks Thie message is sent from the `amd-mod-wayland-core` module.
 */
#define AMD_NOTI_MSG_WAYLAND_LISTENER_TIZEN_INPUT_DEVICE_MANAGER               \
	"wayland.listener.tizen_input_device_manager"

/**
 * @brief Definition for the notification message: The wayland interface is added.
 * @details The interface is `tizen_keyrouter`.
 * @details Input: arg1(int) The interface ID.\n
 *          Input: arg2(int) The version.\n
 *          Input: arg3(struct wl_registry *) The wayland registry.\n
 * @since_tizen 5.5
 *
 * @see __wl_listener_cb()
 * @remarks Thie message is sent from the `amd-mod-wayland-core` module.
 */
#define AMD_NOTI_MSG_WAYLAND_LISTENER_TIZEN_KEYROUTER                          \
	"wayland.listener.tizen_keyrouter"

/**
 * @brief Definition for the notification message: The wayland interface is added.
 * @details The interface is `wl_seat`.
 * @details Input: arg1(int) The interface ID.\n
 *          Input: arg2(int) The version.\n
 *          Input: arg3(struct wl_registry *) The wayland registry.\n
 * @since_tizen 5.5
 *
 * @see __wl_listener_cb()
 * @remarks Thie message is sent from the `amd-mod-wayland-core` module.
 */
#define AMD_NOTI_MSG_WAYLAND_LISTENER_WL_SEAT                                  \
	"wayland.listener.wl_seat"

/**
 * @brief Definition for the notification message: The wayland interface is added.
 * @details The interface is `tizen_launch_appinfo`.
 * @details Input: arg1(int) The interface ID.\n
 *          Input: arg2(int) The version.\n
 *          Input: arg3(struct wl_registry *) The wayland registry.\n
 * @since_tizen 5.5
 *
 * @see __wl_listener_cb()
 * @remarks Thie message is sent from the `amd-mod-wayland-core` module.
 */
#define AMD_NOTI_MSG_WAYLAND_LISTENER_TIZEN_LAUNCH_APPINFO                     \
	"wayland.listener.tizen_launch_appinfo"

/**
 * @brief Definition for the notification message: The wayland interface is added.
 * @details The interface is `tizen_launch_effect`.
 * @details Input: arg1(int) The interface ID.\n
 *          Input: arg2(int) The version.\n
 *          Input: arg3(struct wl_registry *) The wayland registry.\n
 * @since_tizen 5.5
 *
 * @see __wl_listener_cb()
 * @remarks Thie message is sent from the `amd-mod-wayland-core` module.
 */
#define AMD_NOTI_MSG_WAYLAND_LISTENER_TIZEN_LAUNCH_EFFECT                      \
	"wayland.listener.tizen_launch_effect"

/**
 * @brief Definition for the notification message: The wayland interface is added.
 * @details The interface is `tizen_policy`.
 * @details Input: arg1(int) The interface ID.\n
 *          Input: arg2(int) The version.\n
 *          Input: arg3(struct wl_registry *) The wayland registry.\n
 * @since_tizen 5.5
 *
 * @see __wl_listener_cb()
 * @remarks Thie message is sent from the `amd-mod-wayland-core` module.
 */
#define AMD_NOTI_MSG_WAYLAND_LISTENER_TIZEN_POLICY                             \
	"wayland.listener.tizen_policy"

/**
 * @brief Definition for the notification message: The wayland interface is removed.
 * @details Input: arg1(int) The interface ID.\n
 *          Input: arg3(struct wl_registry *) The wayland registry.\n
 * @since_tizen 5.5
 *
 * @see __wl_listener_remove_cb()
 * @remarks Thie message is sent from the `amd-mod-wayland-core` module.
 */
#define AMD_NOTI_MSG_WAYLAND_LISTENER_REMOVE                                   \
	"wayland.listener.remove"

/**
 * @brief Definition for the notification message: Sending the running widget information is started.
 * @details Input: arg2(uid_t) The user ID.\n
 *          Input: arg3(const char*) The instance ID.\n
 *          Output: arg1(int *) The window ID.\n
 * @since_tizen 5.5
 *
 * @see __send_running_info()
 * @remarks Thie message is sent from the `amd-mod-widget` module.
 */
#define AMD_NOTI_MSG_WIDGET_RUNNING_INFO_SEND                                  \
	"widget.running_info.send"

/**
 * @brief Definition for the notification message: The widget will be restarted.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(uid_t) The user ID.\n
 * @since_tizen 5.5
 *
 * @see __on_app_dead()
 * @remarks Thie message is sent from the `amd-mod-widget` module.
 */
#define AMD_NOTI_MSG_WIDGET_ON_APP_DEAD_RESTART                                \
	"widget.on_app_dead.restart"

/**
 * @brief Definition for the notification message: The app group context is destroying.
 * @details Input: arg1(int) The process ID.\n
 *          Input: arg2(int) The window ID.\n
 *          Input: arg3(const char *) The instance ID.\n
 * @since_tizen 5.5
 * @see __destroy_app_group_context()
 */
#define AMD_NOTI_MSG_APP_GROUP_DESTROY_APP_GROUP_CONTEXT                       \
	"app_group.destroy.app_group_context"

#ifdef __cplusplus
}
#endif
