/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "dispatcher.h"
#include "pending_job.h"
#include "private.h"

namespace component_manager {

Dispatcher::Dispatcher() {
  for (int i = 0; i < MAX_WORKER; ++i) {
    std::string name = "compmgr+" + std::to_string(i + 1);
    workers_.emplace_back(new (std::nothrow) Worker(name));
  }
}

Dispatcher::~Dispatcher() = default;

int Dispatcher::Dispatch(std::unique_ptr<Request> req) {
  int cmd = req->GetCmd();
  auto iter = map_.find(cmd);
  if (iter == map_.end()) {
    _W("Failed to find handler. cmd(%d)", cmd);
    return -1;
  }

  auto handler = map_[cmd];
  workers_[GetWorkerID()]->Send(
      std::shared_ptr<PendingJob>(
        new (std::nothrow) PendingJob(std::move(req), handler)));
  return 0;
}

bool Dispatcher::Register(std::shared_ptr<RequestHandler> handler) {
  int cmd = handler->GetCmd();
  auto iter = map_.find(cmd);
  if (iter != map_.end()) {
    _W("Already exists. command[%d]", cmd);
    return false;
  }

  map_[cmd] = std::move(handler);
  _W("Register command[%d]", cmd);
  return true;
}

int Dispatcher::GetWorkerID() {
  int worker_id = 0;
  for (int i = 1; i < MAX_WORKER; i++) {
    if (workers_[worker_id]->GetJobCount() > workers_[i]->GetJobCount())
      worker_id = i;
  }

  return worker_id;
}

}  // namespace component_manager
