/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef DISPATCHER_H_
#define DISPATCHER_H_

#include <map>
#include <memory>

#include "request.h"
#include "request_handler.h"
#include "worker.h"

namespace component_manager {

class Dispatcher {
 public:
  Dispatcher();
  virtual ~Dispatcher();

  int Dispatch(std::unique_ptr<Request> req);
  bool Register(std::shared_ptr<RequestHandler> handler);

 private:
  int GetWorkerID();

 private:
  static const int MAX_WORKER = 2;

 private:
  std::map<int, std::shared_ptr<RequestHandler>> map_;
  std::vector<std::unique_ptr<Worker>> workers_;
};

}  // namespace component_manager

#endif  // DISPATCHER_H_
