/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "request.h"

namespace component_manager {

Request::Request(amd_request_h req) {
  fd_ = amd_request_remove_fd(req);
  cmd_ = amd_request_get_cmd(req);
  target_uid_ = amd_request_get_target_uid(req);
  b_ = tizen_base::Bundle(amd_request_get_bundle(req));
}

Request::Request(int fd, int cmd, uid_t target_uid, tizen_base::Bundle b)
  : fd_(fd), cmd_(cmd), target_uid_(target_uid), b_(std::move(b)) {
}

Request::~Request() {
  if (fd_)
    close(fd_);
}

Request::Request(const Request& req) {
  fd_ = req.fd_;
  cmd_ = req.cmd_;
  target_uid_ = req.target_uid_;
  b_ = req.b_;
}

Request& Request::operator = (const Request& req) {
  if (this != &req) {
    fd_ = req.fd_;
    cmd_ = req.cmd_;
    target_uid_ = req.target_uid_;
    b_ = req.b_;
  }
  return *this;
}

Request::Request(Request&& req) noexcept {
  fd_ = req.fd_;
  req.fd_ = 0;
  cmd_ = req.cmd_;
  req.cmd_ = -1;
  target_uid_ = req.target_uid_;
  req.target_uid_ = 0;
  b_ = std::move(req.b_);
}

Request& Request::operator = (Request&& req) noexcept {
  if (this != &req) {
    fd_ = req.fd_;
    req.fd_ = 0;
    cmd_ = req.cmd_;
    req.cmd_ = -1;
    target_uid_ = req.target_uid_;
    req.target_uid_ = 0;
    b_ = std::move(req.b_);
  }
  return *this;
}

int Request::RemoveFd() {
  int fd = fd_;
  fd_ = 0;
  return fd;
}

int Request::GetFd() const {
  return fd_;
}

int Request::GetCmd() const {
  return cmd_;
}

uid_t Request::GetTargetUid() const {
  return target_uid_;
}

const tizen_base::Bundle& Request::GetBundle() const {
  return b_;
}

}  // namespace component_manager
