/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <aul.h>
#include <aul_comp_info_internal.h>
#include <aul_cmd.h>
#include <errno.h>

#ifdef _GNU_SOURCE
#undef _GNU_SOURCE
#endif
#include <aul_sock.h>

#include "component_info.h"
#include "request_handler/component_info_get.h"
#include "private.h"

namespace component_manager {
namespace request_handler {

ComponentInfoGet::ComponentInfoGet()
  : RequestHandler(COMP_INFO_GET, "COMP_INFO_GET") {
}

int ComponentInfoGet::Handle(std::unique_ptr<Request>& req) {
  RequestHandler::Handle(req);

  auto& b = req->GetBundle();
  std::string component_id = b.GetString(AUL_K_COMPONENT_ID);
  if (component_id.empty()) {
    _E("Failed to get component ID");
    aul_sock_send_raw_with_fd(req->GetFd(), AUL_R_EINVAL, NULL, 0,
        AUL_SOCK_ASYNC);
    return -1;
  }

  aul_compinfo_h handle_inst;
  int ret = aul_compinfo_usr_create(component_id.c_str(), req->GetTargetUid(),
      &handle_inst);
  if (ret != AUL_R_OK) {
    _E("Failed to create component info. error(%d)", ret);
    aul_sock_send_raw_with_fd(req->GetFd(), ret, NULL, 0, AUL_SOCK_ASYNC);
    return ret;
  }

  ComponentInfo info(handle_inst, req->GetTargetUid());
  auto info_b = info.ToBundle();
  bundle* b_raw = info_b.GetHandle();
  ret = aul_sock_send_bundle_with_fd(req->GetFd(), APP_GET_INFO_OK, b_raw,
      AUL_SOCK_ASYNC);
  if (ret < 0) {
    _E("Failed to send bundle data. error(%d)", ret);
    return ret;
  }

  _I("[%s][%d]", GetName().c_str(), GetCmd());
  return 0;
}

}  // namespace request_handler
}  // namespace component_manager
