/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef WORKER_H_
#define WORKER_H_

#include <thread>
#include <memory>
#include <string>
#include <queue>

#include "shared_queue.h"
#include "job.h"

namespace component_manager {

class Worker : public Job::IJobHandler {
 public:
  Worker(std::string name);
  ~Worker();

  void Send(std::shared_ptr<Job> job);
  void Run();
  unsigned int GetJobCount() const;

 private:
  bool Join();
  void Quit();
  void SetComm();
  void OnJob() override;

 private:
  std::string name_;
  std::thread thread_;
  bool done_ = false;
  SharedQueue<std::shared_ptr<Job>> queue_;
};

}  // namespace component_manager

#endif  // WORKER_H_
