/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

/**
 * @brief Called when the image file is created.
 *
 * @param[in]   image           The image file
 * @param[in]   user_data       The user data passed from the callback registration function
 */
typedef void (*rua_image_monitor_event_cb)(const char *image, void *user_data);

/**
 * @brief Clears all image files.
 */
void _rua_image_monitor_clear_all(void);

/**
 * @brief Clears the image file.
 *
 * @param[in]   image           The image file
 */
void _rua_image_monitor_clear(const char *image);

/**
 * @brief Sets the event callback function.
 *
 * @param[in]   callback        The callback function to be called when the image file is created
 * @param[in]   user_data       The user data to be ppased to the callback function
 * @return      @c 0 on success,
 *              otherwise a negative error value
 */
int _rua_image_monitor_set_event_cb(rua_image_monitor_event_cb callback,
		void *user_data);

/**
 * @brief Initializes the image monitor.
 *
 * return       @c 0 on success,
 *              otherwise a negative error value
 */
int _rua_image_monitor_init(void);

/**
 * @brief Finalizes the image monitor.
 */
void _rua_image_monitor_fini(void);
