/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

/**
 * @brief Gets the ID of the instance.
 *
 * @return @c an instance ID on success,
 *         otherwise a nullptr
 */
const char *_rua_launch_context_get_id(void);

/**
 * @brief Gets the name of the instance.
 *
 * @return @c a instance name on success,
 *         otherwise a nullptr
 */
const char *_rua_launch_context_get_name(void);

/**
 * @brief Gets the icon path.
 *
 * @return @c an icon path on success,
 *         otherwise a nullptr
 */
const char *_rua_launch_context_get_icon(void);

/**
 * @brief Gets the URI.
 *
 * @return @c URI on success,
 *         otherwise a nullptr
 */
const char *_rua_launch_context_get_uri(void);

/**
 * @brief Releases the launch context.
 */
void _rua_launch_context_free(void);

/**
 * @brief Initialize the launch context.
 *
 * @return @c 0 on succes,
 *         otherwise a negative error value
 */
int _rua_launch_context_init(void);

/**
 * @brief Finalize the launch context.
 */
void _rua_launch_context_fini(void);
