/*
 * Copyright (c) 2018 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#define _GNU_SOURCE
#include <stdio.h>
#include <stdarg.h>
#include <amd.h>

#include "amd_watchdog_private.h"
#include "amd_watchdog_logger.h"

#define LOG_FILE "amd_watchdog.log"
#define LOG_PATH LOGGER_PATH "/" LOG_FILE

static amd_logger_h __logger;

int _watchdog_logger_print(const char *tag, const char *format, ...)
{
	char format_buf[256];
	va_list ap;

	va_start(ap, format);
	vsnprintf(format_buf, sizeof(format_buf), format, ap);
	va_end(ap);

	return amd_logger_print(__logger, tag, format_buf);
}

int _watchdog_logger_init(void)
{
	int ret;

	_D("Watchdog logger init");
	ret = amd_logger_create(LOG_PATH, &__logger);
	if (ret < 0)
		return ret;

	return 0;
}

void _watchdog_logger_fini(void)
{
	_D("Watchdog logger fini");
	amd_logger_destroy(__logger);
}
